
$.fn.extend({
  animateCss: function (animationName) {
    var animationEnd = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';
    $(this).addClass('animated ' + animationName).one(animationEnd, function() {
      $(this).removeClass('animated ' + animationName);
    });
  }
});

var defaultLocation = 'Invercargill, New Zealand';
var lowRating = false;
var lowestRating = 5;
var lowRatingNiceName = '';
var lowRatingCount = 0;
var lowRatingTrigger = 3;

// On star click
$('#rating-buttons i').on('click', function(e){

  e.preventDefault()
  e.stopPropagation();

  // Set all stars to blank
  $(this).parent().find('i').removeClass('fa-star').addClass('fa-star-o');

  // Change class and trigger a chain of changes to previous elements
  $(this).removeClass('fa-star-o').addClass('fa-star').trigger('classChange').animateCss('tada');

  checkNavVisibility();

});

$('#rating-buttons i').on('classChange', function(){

  // Change previous star to filled
  $(this).prev().removeClass('fa-star-o').addClass('fa-star').trigger('classChange').animateCss('tada');

  starCount = $(this).parent().find('.fa-star').length;

  $(this).parent().find('input').val( starCount );

  lowRating = false;
  lowestRating = 5;
  lowRatingCount = 0;

  $.each($('.rating-field'), function(i,e){

    rating = e.value;

    if (rating <= lowRatingTrigger && typeof rating != 'undefined' && rating != '')
    {

      lowRating = true;

      lowRatingCount++;

      if (rating <= lowestRating)
      {
        lowRatingNiceName = e.getAttribute('data-nicename');
        lowestRating = rating;
      }

    }

  });

  console.log(lowestRating);
  console.log(lowRating);
  console.log(lowRatingCount);

});

var defaultFeedbackHeader = $('#feedback-header').html();
var defaultFeedbackPlaceholder = $('#feedback-field').attr('placeholder');

function changeFeedbackPlaceholder()
{

  // if the lowest rating is lower than 3
  if (lowestRating <= lowRatingTrigger)
  {
    $('#feedback-header').html('What went wrong?');

    if (lowRatingCount > 1)
    {
      $('#feedback-field').attr('placeholder', 'We see you rated us poorly for a number of questions. Please help us improve by providing feedback. Thank you.');
    }
    else
    {
      $('#feedback-field').attr('placeholder', 'We see you gave us a rating of ' + lowestRating + ' for ' + lowRatingNiceName + '. Please help us improve by providing feedback. Thank you.');
    }
  }
  else
  {
    $('#feedback-header').text(defaultFeedbackHeader);
    $('#feedback-field').attr('placeholder', defaultFeedbackPlaceholder);
  }

}

$('.content-slide').css('width', screen.width);

String.prototype.capitalize = function() {
  return this.replace(/(?:^|\s)\S/g, function(a) { return a.toUpperCase(); });
};

var slideCount = $('.content-slide').length;
var currentSlide = 1;
var mapSlide = 6;

function checkNavVisibility()
{


  if (currentSlide > 1)
  {
    $('.nav-left').fadeIn();
  }
  else
  {
    $('.nav-left').fadeOut();
  }


  // last slide
  if (currentSlide < slideCount && $('input[name="overall_rating"]').val() != '')
  {
    $('.nav-right').fadeIn();
  }
  else
  {
    $('.nav-left').fadeOut();
    $('.nav-right').fadeOut();

    if (currentSlide == slideCount)
    {
      $.ajax({
        url: 'submit',
        type: 'POST',
        data: $('form').serialize(),
        success: function(){

        }
      });

      $('#finish-name').text($('input[name="full_name"]').val().capitalize());

    }

    setTimeout(function(){
      if (currentSlide == slideCount)
      {
        $('#back-to-start').trigger('click');
      }
    }, 10000);

  }


  if (currentSlide == slideCount - 1)
  {
    $('.nav-right a i').removeClass('fa-arrow-circle-o-right').addClass('fa-check-circle-o submit');
  }
  else
  {
    $('.nav-right a i').removeClass('fa-check-circle-o submit').addClass('fa-arrow-circle-o-right');
  }


}



checkNavVisibility();

slideAmount = screen.width;

$('.nav-right').on('click', function(e){

  e.preventDefault();

  $(this).animateCss('pulse');

  if (currentSlide < slideCount)
  {
    slide(slideAmount * - currentSlide);
    currentSlide++;

    checkNavVisibility();
    checkMapSlide();
    changeFeedbackPlaceholder();
  }

});

$('.nav-left').on('click', function(e){

  e.preventDefault();

  $(this).animateCss('pulse');

  if (currentSlide > 1)
  {
    currentSlide--;

    slide(slideAmount * - (currentSlide - 1));

    console.log(slideAmount * (currentSlide - 1));

    checkNavVisibility();
    checkMapSlide();
    changeFeedbackPlaceholder();
  }

});

checkMapSlide();


function slide(newLeft)
{

  $('.content-slide').animate({left: newLeft}, 700, function(){

    setTimeout(function(){
      $('.nav-left, .nav-right').css('pointer-events', '');
    });

  });

  $('.nav-left, .nav-right').css('pointer-events', 'none').css('opacity');


}

$('button').on('click', function(e){
  e.preventDefault();
});

$('#back-to-start').on('click', function(e){

  e.preventDefault();

  currentSlide = 1;

  slide(0);

  $('input[type="text"], input[type="hidden"], input[type="email"], textarea').val('');

  $('#rating-buttons i').removeClass('fa-star').addClass('fa-star-o');

  $(':checkbox').prop('checked', false);

  $(':checkbox').parent().find('label i').removeClass('fa-check-square').addClass('fa-square-o');

  checkNavVisibility();
});

$('#back-to-start').trigger('click'); // clear all forms etc

function checkMapSlide()
{
  if (currentSlide == mapSlide)
  {
    $('#content').addClass('map-pointer-events');

    $('#logo-light').hide();
    $('#logo-dark').show();

    $("#location-field").geocomplete("find", defaultLocation);

    $('#visitor-map').css({'opacity': '1'});

    setTimeout(function(){
      $('#location-field').val('');
    }, 500);

  }
  else
  {
    $('#content').removeClass('map-pointer-events');

    $('#logo-light').show();
    $('#logo-dark').hide();


    // delay to load the map before hiding it, otherwise it'll sometimes break?
    if ($('#visitor-map').is(':visible') && currentSlide == 1)
    {
      setTimeout(function(){
        $('#visitor-map').css({'opacity':'0'});
      }, 3000);
    }
    else
    {
      $('#visitor-map').css({'opacity':'0'});
    }


  }
}


$('#location-field').on('change', function(){

  url =  'https://www.google.com/maps/embed/v1/place?key=AIzaSyCU9huEJHTzMBfGWdPA4RQgcBzGwiETopQ&q=';

  $('#visitor-map').attr('src', url + $(this).val());

});

$(':checkbox').change(function() {

  if (this.checked)
  {
    $(this).parent().find('label i').removeClass('fa-square-o').addClass('fa-check-square');
  }
  else
  {
    $(this).parent().find('label i').removeClass('fa-check-square').addClass('fa-square-o');
  }

});

$('.focus-nearest-field').on('click', function(){

  $(this).parent().find('label input').select();

});

$('input[name="refferal_brochure"]').on('focus', function(){

  $(this).attr('placeholder', 'What brochure?');

});

$('input[name="refferal_brochure"]').on('blur', function(){

  $(this).attr('placeholder', 'Brochure');

});


$('.checkbox-field').on('blur, click, focus, keyup', function(){

  if ($(this).val() != '')
  {
    $(this).parent().parent().find('input[type="checkbox"]').prop('checked', true).trigger('change');
  }
  else
  {
    $(this).parent().parent().find('input[type="checkbox"]').prop('checked', false).trigger('change');
  }


});

//slide(6 * - slideAmount);
